@@ -21,6 +21,10 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
+// StringReplacer includes.
+#include "stringreplacerconf.h"
+#include "stringreplacerconf.moc"
+
 // Qt includes.
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
@@ -49,15 +53,11 @@
 #include "selectlanguagedlg.h"
 #include "filterconf.h"
 
-// StringReplacer includes.
-#include "stringreplacerconf.h"
-#include "stringreplacerconf.moc"
-
 /**
 * Constructor 
 */
-StringReplacerConf::StringReplacerConf( QWidget *parent, const QStringList& args ) :
-    KttsFilterConf(parent),
+StringReplacerConf::StringReplacerConf( QWidget *parent, const QVariantList& args ) :
+    KttsFilterConf(parent, args),
     m_editDlg(0),
     m_editWidget(0)
 {
@@ -308,10 +308,10 @@ QString StringReplacerConf::saveToFile(const QString& filename)
     }
 
     // Application ID
-    QString appId = appIdLineEdit->text().replace(" ", "");
+    QString appId = appIdLineEdit->text().remove(' ');
     if ( !appId.isEmpty() )
     {
-        QStringList appIdList = appId.split( ",", QString::SkipEmptyParts );
+        QStringList appIdList = appId.split( ',', QString::SkipEmptyParts );
         for ( int ndx=0; ndx < appIdList.count(); ++ndx )
         {
             QDomElement appIdElem = doc.createElement( "appid" );
@@ -453,7 +453,7 @@ void StringReplacerConf::slotLanguageBrowseButton_clicked()
         s2.replace( s1, language );
         s2.replace( i18n("Multiple Languages"), language );
     }
-    s2.replace(" ()", "");
+    s2.remove(" ()");
     if ( !s2.contains("(") && !language.isEmpty() ) s2 += " (" + language + ')';
     nameLineEdit->setText(s2);
     configChanged();
@@ -665,8 +665,8 @@ void StringReplacerConf::slotMatchButton_clicked()
     if ( !m_editWidget ) return;
     if ( !m_editDlg ) return;
     if ( !m_reEditorInstalled ) return;
-    QDialog *editorDialog = 
-        KServiceTypeTrader::createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor" );
+    KDialog *editorDialog = 
+        KServiceTypeTrader::createInstanceFromQuery<KDialog>( "KRegExpEditor/KRegExpEditor" );
     if ( editorDialog )
     {
         // kdeutils was installed, so the dialog was found.  Fetch the editor interface.
